// Sparta-Mod Skills 0-7 (1-8)

// Set the health from the player
public Skill_Health( id )
{
	// Has the player the skill?
	if ( Player_Skill[id][SKILL_HEALTH] <= 0 && !g_AllowGivTakeSkill )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Set the life from the player
	new TempHealth = ( 100 + ( HEALTH_FOR_SKILL * Player_Skill[id][SKILL_HEALTH] ) );
	
	// The player is silenced, he get no life
	if ( Player_Silenced[id] && get_user_health( id ) < 100 )
	{
		return PLUGIN_CONTINUE;
	}
	
	// The player is silenced but has more as 100 life!
	else if ( Player_Silenced[id] )
	{
		TempHealth = 100;
	}
	
	// set the health
	set_user_health ( id, TempHealth );
	
	return PLUGIN_CONTINUE;
}

// Set the gravity from the player (levitation)
public Skill_Gravity( id )
{
	// Has the player the skill?
	if ( Player_Skill[id][SKILL_LEVITATION] <= 0 && !g_AllowGivTakeSkill )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Set the gravity from the player
	new const g_ServGravity = get_cvar_num( "sv_gravity" );
	
	new Float:s_NewGravity = ( LEVITATION_FOR_SKILL / float ( g_ServGravity ) ); 
	s_NewGravity = ( s_NewGravity * float ( Player_Skill[id][SKILL_LEVITATION] ) );
	s_NewGravity = 1.0 - s_NewGravity;
	
	// The player is silenced, he get no gravity
	if ( Player_Silenced[id] )
	{
		s_NewGravity = 1.0; // Default gravity
	}
	
	// Set the gravity
	set_user_gravity ( id, s_NewGravity );
	
	return PLUGIN_CONTINUE;
}

// Set the Speed of a player
public Skill_SetSpeed( taskid )
{
	new id = taskid - TASK_SPEED;
	
	// we have to request this because we call this function sometimes alone
	if ( !is_user_alive( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Has the player the skill?
	if ( Player_Skill[id][SKILL_SPEED] <= 0 && !g_AllowGivTakeSkill )
	{
		return PLUGIN_CONTINUE;
	}
	
	// We calculate the new speed
	new Float:speed = DEFAULT_SPEED + ( SPEED_FOR_SKILL * float( Player_Skill[id][SKILL_SPEED] ) );
	
	// The player is silenced, he get no speed
	if ( Player_Silenced[id] )
	{
		speed = DEFAULT_SPEED;
	}
	
	// An ultimate or a skill want that the player can't run. We accept this!
	else if ( get_user_maxspeed( id ) == 0.1 )
	{
		speed = 0.1;
	}
	
	// He has a poisen!
	else if (  get_user_maxspeed( id ) == SPEED_FOR_SKILL )
	{
		speed = float( SPEED_FOR_SKILL );
	}
	
	// Set the maxspeed
	set_user_maxspeed ( id , speed );
		
	// Set the other speed's so we are sure they don't run faster
	client_cmd ( id, "cl_forwardspeed %f;cl_backspeed %f; cl_sidespeed %f", speed, speed, speed );
			
	return PLUGIN_CONTINUE;
}

// set the Invisibility from the player
public Skill_Invisible( id )
{
	// Has the player the skill?
	if ( Player_Skill[id][SKILL_INVISIBLE] <= 0 && !g_AllowGivTakeSkill )
	{
		return PLUGIN_CONTINUE;
	}
	
	if ( g_AllowGivTakeSkill || Player_Silenced[id] )
	{
		// The player is no more invisible
		set_user_rendering( id );
		
		return PLUGIN_CONTINUE;
	}
	
	// Get the level
	static TempLevel;
	TempLevel = Player_Skill[id][SKILL_INVISIBLE];
	
	// Get the right invislevel
	if ( Player_Skill[id][SKILL_INVISIBLE] >= 1 )
	{
		TempLevel = Skill_Invis[TempLevel-1];
	}
	
	// Set the rendering
	set_user_rendering( id, kRenderFxNone, 0, 0, 0, kRenderTransTexture, TempLevel );
	
	return PLUGIN_CONTINUE;
}

// Check if the player has critical strike skilled and set the damage higher
public Float:Skill_CriticalStrike( idAttacker, idVictim, Float:Damage )
{
	// Has the player the skill?
	if ( Player_Skill[idAttacker][SKILL_CRITICAL] <= 0 || Player_Silenced[idAttacker] )
	{
		return Damage;
	}
	
	// Will this be a crit?
	if ( random_float( 0.0, 1.0 ) <= CRITICAL_STRIKE_CHANCE )
	{
		// Save the maxcrit damage
		new Float:MaxDamage = float( Skill_Critical[Player_Skill[idAttacker][SKILL_CRITICAL]-1] );
		
		// We need a var for the MinDamage
		new Float:MinDamage = 0.0;
		
		// The player isn't on the first level so get damage from the last level
		if ( Player_Skill[idAttacker][SKILL_CRITICAL] != 1 )
		{
			MinDamage = float( Skill_Critical[Player_Skill[idAttacker][SKILL_CRITICAL]-2] );
		}
		
		// Add the random damage to the var
		Damage += random_float( MinDamage, MaxDamage );
		
		// Get the name from the two players
		static VictimName[32], AttackerName[32];
		get_user_name( idAttacker, AttackerName, charsmax( AttackerName ) );
		get_user_name( idVictim, VictimName, charsmax( VictimName ) );
		
		// Send the two players a message
		client_print( idAttacker, print_chat, "%s You strike a critical blow to %s", SPARTA_NAME, VictimName );
		client_print( idVictim, print_chat, "%s You were hit by a critical strike from %s", SPARTA_NAME, AttackerName );
	}
	
	return Damage;
}

// Shocking touch - Shock the player
public Skill_ShockingTouch( idattacker, idvictim )
{
	if ( Player_Skill[idattacker][SKILL_SHOCKING] <= 0 || Player_Silenced[idattacker] )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Will this hit activate shocking touch?
	if ( random_float( 0.0, 1.0 ) <= SHOCKING_TOUCH_CHANCE )
	{
		// The player can't nomore run
		set_user_maxspeed( idvictim, 0.1 );
		
		// Play the impale sound
		emit_sound( idvictim, CHAN_STATIC, g_Sound[IMPALE_SOUND], 1.0, ATTN_NORM, 0, PITCH_NORM );
		
		// The player isn't invisible, we can glow him
		if ( Player_Skill[idvictim][SKILL_INVISIBLE] == 0 )
		{
			set_user_rendering( idvictim, kRenderFxGlowShell, 255, 255, 255, kRenderNormal, 16 );
		}
		
		// After 2.5 seconds the player is no more shocked
		set_task ( 2.5, "RemoveShock", ( idvictim + TASK_SHOCK ) );
		
		// Show the two players a message
		client_print ( idvictim, print_chat, "%s You are currently shocked", SPARTA_NAME );
		client_print ( idattacker, print_chat, "%s You have shocked the enemy", SPARTA_NAME );
	}
	
	return PLUGIN_CONTINUE;
}

// Remove the shock effect
public RemoveShock( id )
{
	id -= TASK_SHOCK;
	
	if ( !is_user_alive( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// We have to set the speed to DEFAULT because on 0.1 the function will not set the speed
	set_user_maxspeed( id, DEFAULT_SPEED );
	
	// Set him the right speed
	set_task ( 0.4, "Skill_SetSpeed", ( id + TASK_SPEED ) );
	
	// Remove the glow effect
	if ( Player_Skill[id][SKILL_INVISIBLE] == 0 )
	{
		set_user_rendering( id );
	}
	
	return PLUGIN_CONTINUE;
}

// Silence the player ( Can't start ultimates and have no skills )
public Skill_Silence( idattacker, idvictim )
{
	if ( Player_Skill[idattacker][SKILL_SILENCE] <= 0 || Player_Silenced[idattacker] )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Will this hit activate silence?
	if ( random_float( 0.0, 1.0 ) <= SILENCE_CHANCE )
	{
		// The player can't use ultimates and has no skills
		Player_Silenced[idvictim] = true;
		
		// Play the banish sound
		emit_sound( idvictim, CHAN_STATIC, g_Sound[BANISH_SOUND], 1.0, ATTN_NORM, 0, PITCH_NORM );
		
		// Calculate the silence time
		static Float:SilenceTime;
		SilenceTime = DEFAULT_SILENCE_TIME * Player_Skill[idattacker][SKILL_SILENCE];
		
		// Set off the silence after a spezific time
		set_task ( SilenceTime, "RemoveSilence", ( idvictim + TASK_SILENCE ) );
		
		// Set all skills off
		Update_Skills( idvictim );
		
		// Show the two players a message
		client_print ( idvictim, print_chat, "%s You are silenced for %d seconds", SPARTA_NAME, floatround( SilenceTime ) );
		client_print ( idattacker, print_chat, "%s You have silenced the enemy for %d seconds", SPARTA_NAME, floatround( SilenceTime ) );
	}
	
	return PLUGIN_CONTINUE;
}

// Remove the silence
public RemoveSilence( id )
{
	id -= TASK_SILENCE;
	
	if ( !is_user_connected( id ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Remove the silence
	Player_Silenced[id] = false;
	
	// The player is alive, set him the old skills back
	if ( is_user_alive( id ) )
	{
		Update_Skills( id );
	}
	
	return PLUGIN_CONTINUE;
}
		
	
/* AMXX-Studio Notes - DO NOT MODIFY BELOW HERE
*{\\ rtf1\\ ansi\\ deff0{\\ fonttbl{\\ f0\\ fnil Tahoma;}}\n\\ viewkind4\\ uc1\\ pard\\ lang1031\\ f0\\ fs16 \n\\ par }
*/
