/* Sparta-Mod
*   
*  by DA
*
*  This program is free software; you can redistribute it and/or modify it
*  under the terms of the GNU General Public License as published by the
*  Free Software Foundation; either version 2 of the License, or (at
*  your option) any later version.
*
*  This program is distributed in the hope that it will be useful, but
*  WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
*  General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software Foundation,
*  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
*  In addition, as a special exception, the author gives permission to
*  link the code of this program with the Half-Life Game Engine ("HL
*  Engine") and Modified Game Libraries ("MODs") developed by Valve,
*  L.L.C ("Valve"). You must obey the GNU General Public License in all
*  respects for all of the code used other than the HL Engine and MODs
*  from Valve. If you modify this file, you may extend this exception
*  to your version of the file, but you are not obligated to do so. If
*  you do not wish to do so, delete this exception statement from your
*  version.
*/	

#pragma tabsize	0

#include <amxmodx>
#include <amxmisc>
#include <fakemeta>
#include <hamsandwich>
#include <cstrike>
#include <csx>
#include <fun>
#include <sqlx>
#include <nvault>

#define VERSION	"0.71"

// --- Main Includes ---
#include "sparta/defs.inl"		// Defines
#include "sparta/var.inl"		// Global variables
#include "sparta/cvars.inl"		// Admin commands / CVAR's
#include "sparta/admin.inl" 		// Admin functions
#include "sparta/nvault.inl"		// Save by nvault
#include "sparta/mysql.inl"     	// sqlX functions
#include "sparta/other.inl" 		// Some userfull functions
#include "sparta/graphics.inl"		// Graphics for the mod
#include "sparta/config.inl"		// Config settings
#include "sparta/player.inl"		// Player settings
#include "sparta/XP.inl"		// XP functions
#include "sparta/events.inl"		// Event functions
#include "sparta/handle.inl"		// Handle say and menus
#include "sparta/motd.inl" 		// Create motds

// --- Ultimates ---
#include "sparta/ultimates.inl"		// Global ultimate functions
#include "sparta/ultimate1.inl"		// Air Flash
#include "sparta/ultimate2.inl" 	// Blast Wave
#include "sparta/ultimate3.inl" 	// Napalm Attack
#include "sparta/ultimate4.inl"		// Chainlightning

// --- Skills ---
#include "sparta/skills.inl" 		// Global skill functions
#include "sparta/skills1.inl" 		// Skills from 0-7 (1-8)

// --- UtilMenus ---
#include "sparta/utilmenus.inl"		// Utilmenus in spartamod

public plugin_init()
{
	register_plugin ( "Sparta-Mod (300)", VERSION, "DA" );
	
	// Event's
	register_event ( "CurWeapon", "Strip_Player_Weapons", "be", "1=1" );
	register_event ( "HLTV", "NewRound", "a", "1=0", "2=0" );
	register_event ( "SendAudio", "on_TerroristWin", "a", "2=%!MRAD_terwin" );
	register_event ( "SendAudio", "on_CTWin"	, "a", "2=%!MRAD_ctwin" );	
	register_logevent ( "RoundEnd", 2, "1=Round_End" );
	register_logevent ( "RoundStart", 2, "1=Round_Start" );
	register_logevent ( "on_FreezeTimeComplete", 2, "0=World triggered", "1=Round_Start" );
	register_logevent ( "on_PlayerAction", 3	, "1=triggered" );
	
	// hmm, a Sandwich!
	RegisterHam ( Ham_Item_Deploy, "weapon_knife", "Set_Player_Knife", 1 );
	RegisterHam ( Ham_Item_AttachToPlayer, "weapon_knife", "Set_Player_Knife", 1 );
	RegisterHam ( Ham_Spawn, "player", "Set_User_Abilities", 1 );
	RegisterHam ( Ham_TakeDamage, "player", "PlayerGetDamage" );
	RegisterHam ( Ham_Touch, "func_buyzone", "bacon_touch_buyzone" );
	
	// Register forwards
	register_forward ( FM_TraceLine, "TRIGGER_TraceLine" );
			
	// From wc3ft
	gmsgStatusText = get_user_msgid( "StatusText" );
	gmsgScoreInfo = get_user_msgid( "ScoreInfo" );
	gmsgDeathMsg = get_user_msgid( "DeathMsg" );
	gmsgScreenShake	= get_user_msgid( "ScreenShake"	);
	gmsgScreenFade = get_user_msgid( "ScreenFade" );
	gmsgStatusIcon = get_user_msgid( "StatusIcon" );
	
	// Menues registers
	register_menu ( "SelectUlt", 1023, "SetUltimate" );
	register_menu ( "ShowSPMenu", 1023, "SetSPMenuOption" );
	register_menu ( "SelectSkill", 1023, "SetSkillMenu" );
	register_menu ( "UtilMenuOne", 1023, "SelectUtilMenuOne" );
	
	// Load the CVAR's	
	CVAR_Init(); 
	
	// Load the XPTables
	XP_TABLES();
	
	// Delete the buyzone
	if ( get_pcvar_num( sparta_mod_on ) )
	{
		RemoveEntityAll ( "func_buyzone" );
	}
	
	// Execute the config file after a little time
	set_task ( 0.4, "ExecuteConfig" );
		
	// We save the xp, so start the right connection
	if ( get_pcvar_num( sp_savexp ) )
	{
		set_task ( 1.2, "Start_Connection" );
	}
	
	// We set a global task for the ultimate delay
	set_task ( 1.0, "CheckUlt", TASK_GLOBALULT, "", 0, "b" );
	
	return PLUGIN_CONTINUE;
}

// Precache things
public plugin_precache()
{
	// Precache all blades (the names are in defs.inl)
	static i;
	for ( i = 0; i < ( sizeof g_knifes ); ++i )
	{
		if ( file_exists ( g_knifes[i] ) )
		{
			precache_model ( g_knifes[i] );
		}
	}
	
	// Precache all sprites
	static Temp_Sprites[MAX_SPRITES][64];

	copy ( Temp_Sprites[EXPLOSION_SPRITE], 63,  "sprites/zerogxplode.spr" );
	copy ( Temp_Sprites[SMOKE_SPRITE], 63, "sprites/steam1.spr" );
	copy ( Temp_Sprites[SHOCKWAVE_SPRITE], 63, "sprites/shockwave.spr" );
	copy ( Temp_Sprites[LIGHTNING_SPRITE], 63, "sprites/lgtning.spr" ); 
	copy ( Temp_Sprites[TRAIL_SPRITE], 63, "sprites/smoke.spr" );
	
	static temp[64];
	
	// We have to check if all files are on the server
	for ( i = 0; i < ( sizeof g_Sound ); ++i )
	{
		if ( containi( g_Sound[i], "sparta" ) != -1 )
		{
			formatex ( temp, charsmax( temp ), "sound/%s", g_Sound[i] );
			
			if ( !file_exists( temp ) )
			{
				log_amx ( "ERROR. Can't find sound %s", g_Sound[i] );
			}
		}
	}
	
	for ( i = 0; i < MAX_SPRITES; ++i )
	{
		g_Sprites[i] = precache_model ( Temp_Sprites[i] );
	}
	
	// Precache all sounds (the names are in defs.inl)
	for ( i = 0; i < ( sizeof g_Sound ); ++i )
	{
		precache_sound ( g_Sound[i] );
	}
}

// Player logged on steam
public client_authorized(id)
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Need it for access
	static auth[32];
	get_user_authid ( id, auth, charsmax( auth ) );
	
	// Then the player doesn't have a steam id, lets make them reconnect
	if ( equal ( auth, "STEAM_ID_PENDING" ) )
	{
		client_cmd ( id, "reconnect" );
	}
	
	// Ok, should we work with savexp?
	else if ( get_pcvar_num ( sp_savexp ) && !is_user_bot( id ) )
	{
		GetPlayerXP ( id + TASK_CONNECT_XP );
	}
	
	// The player is a bot
	else if ( is_user_bot( id ) )
	{
		Player_Level[id] = get_pcvar_num( sp_botlevel );
		Player_XPs[id] = g_XPforLevel[Player_Level[id]];
	}
	
	return PLUGIN_CONTINUE;
}

// Player disconnect from the server
public client_disconnect( id )
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	// Save the user's xp if savexp enabled
	if ( get_pcvar_num ( sp_savexp ) && !is_user_bot( id ) )
	{
		SavePlayerXP( id );
	}
	
	// The player is out, we nomore need the data from him
	Player_Level[id] = 0;
	Player_XPs[id] = 0;
	Player_Ultimate[id] = 0;
	Player_SkillData[id][SKILL_SIDE] = 0;
	Player_SkillData[id][AVAILABLE_SKILLS] = 0;
	Player_Silenced[id] = false;
	Player_ItemData[id][UTILMENU_ONE] = ITEM_NONE;
	
	// Reset the skills
	static i;
	for ( i = 0; i < MAX_SKILLS; ++i )
	{
		Player_Skill[id][i] = 0;
	}
	
	return PLUGIN_CONTINUE;
}

// Close the Plugin
public plugin_end()
{
	if ( !get_pcvar_num( sparta_mod_on ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	if ( !get_pcvar_num( sp_savexp ) )
	{
		return PLUGIN_CONTINUE;
	}
	
	static players[32], num, i;
	get_players ( players, num, "c" );
	
	// We save all the xps from the players
	for ( i = 0; i < num; ++i )
	{
		SavePlayerXP( players[i] );
	}
	
	// Close nvault file
	if ( get_pcvar_num( sp_typesave ) == 1 )
	{
		NVAULT_CloseNow();
	}
	
	// Close the MYSQL connection
	else
	{
		MYSQL_Close();
	}
	
	return PLUGIN_CONTINUE;
}
	
	
